==> ox-0.4.6.tar.gz: ox-0.4.6/.todo.md <==
- [ ] Config and documentation improvement
  - [ ] Look at old ox.ron config - add anything that is missing in new ox
  - [ ] Allow reloading of config file
  - [ ] Include smaller version of config file for example
  - [ ] Update documentation
    - [ ] and readme - show new key bindings i.e. line moving and word deleting
  - [ ] Plugins can feed into status line / greeting message
  - [ ] Edit tab width
  - [ ] More status / greeting message interpolation options
  - [ ] Multiple plug-ins being able to use the same key binding*
- [ ] General tweaks
  - [ ] Group events together when committing for undo/redo
- [ ] Safety update
  - [ ] Document backups
  - [ ] Panic busting & nicer panics / errors*
- [ ] Splitting*
  - [ ] Move towards tree structure of document groups
    - [ ] Clean API from in-house Tree struct
  - [ ] Actually render splits on the screen
  - [ ] Split commands / API
  - [ ] Vigorously test resizing / setting window size weirdly
- [ ] Github issue busting
  - [ ] Go through each github issue and implement changes
- [ ] Plugin overhaul
  - [ ] HTML editor*
  - [ ] HTML tag pairs*
  - [ ] Todo lists*
  - [ ] Typing speed measurement
  - [ ] Pomodoro timer
- [ ] Selection, copying, pasting
  - [ ] Mouse interaction 
  - [ ] Wayland clipboard support 
- [ ] Supporting infrastructure
  - [ ] Configuration assistant
  - [ ] Syntax highlighting assistant
  - [ ] Discord rich presence
- [ ] File tree
  - [ ] Implement file tree*
- [ ] Code prettifier
  - [ ] Implement code prettification infrastructure
- [ ] Autocomplete
  - [ ] Implement code autocomplete infrastructure
- [X] General bug fixes
  - [X] Update bulit-in help message and greeting message
  - [X] Fix status line duplication issues
  - [X] Search and replace needs to stop crashing due to syntax highlighting update
  - [X] Search and replace needs to hide cursor
  - [X] Replace command needs to update syntax
  - [X] Undo / Redo need to be committed more*
  - [X] Search needs to break beyond what has been loaded into buffer*
  - [X] Traverse over space groups as per tab width*
  - [X] Cursor movement improvement
  - [X] Fix incorrect behaviour on deletion of space tabs
  - [X] Fix undo / redo not updating syntax highlighting

==> ox-0.5.1.tar.gz: ox-0.5.1/.todo.md <==
- [ ] Config and documentation improvement
  - [ ] Look at old ox.ron config - add anything that is missing in new ox
  - [ ] Allow reloading of config file
  - [ ] Include smaller version of config file for example
  - [ ] Update documentation
    - [ ] and readme - show new key bindings i.e. line moving and word deleting
  - [ ] Plugins can feed into status line / greeting message
  - [ ] Edit tab width
  - [ ] More status / greeting message interpolation options
  - [ ] Multiple plug-ins being able to use the same key binding*
- [ ] General tweaks
  - [ ] Group events together when committing for undo/redo
  - [ ] Better word traversal
- [ ] Bug Fixes
  - [ ] Fix key binding error when pressing the underscore key
  - [ ] Investigate not being able to edit the last line of files
- [ ] Safety update
  - [ ] Document backups
  - [ ] Panic busting & nicer panics / errors*
- [ ] Splitting*
  - [ ] Move towards tree structure of document groups
    - [ ] Clean API from in-house Tree struct
  - [ ] Actually render splits on the screen
  - [ ] Split commands / API
  - [ ] Vigorously test resizing / setting window size weirdly
- [ ] Plugin overhaul
  - [ ] HTML editor*
  - [ ] HTML tag pairs*
  - [ ] Todo lists*
  - [ ] Typing speed measurement
  - [ ] Pomodoro timer
- [ ] Selection, copying, pasting
  - [ ] Mouse interaction 
  - [ ] Wayland clipboard support 
- [ ] Supporting infrastructure
  - [ ] Configuration assistant
  - [ ] Syntax highlighting assistant
  - [ ] Discord rich presence
- [ ] File tree
  - [ ] Implement file tree*
- [ ] Code prettifier
  - [ ] Implement code prettification infrastructure
- [ ] Autocomplete
  - [ ] Implement code autocomplete infrastructure
